==> binnie-mods-1.11.2-2.1.0.6-sources.jar: binnie/extratrees/block/wood/BlockETSlab.java <==
package binnie.extratrees.block.wood;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.util.ResourceLocation;

import forestry.arboriculture.blocks.BlockForestrySlab;

import binnie.Constants;
import binnie.extratrees.block.EnumETLog;
import binnie.extratrees.block.property.PropertyETWoodType;

public abstract class BlockETSlab extends BlockForestrySlab<EnumETLog> {
	private BlockETSlab(boolean fireproof, int blockNumber) {
		super(fireproof, blockNumber);
		String name = "slabs.";
		if (fireproof) {
			name += "fireproof.";
		}
		if (func_176552_j()) {
			name += "double.";
		}
		name += blockNumber;
		setRegistryName(new ResourceLocation(Constants.EXTRA_TREES_MOD_ID, name));
		func_149663_c(name);
	}

	public static List<BlockETSlab> create(boolean fireproof, final boolean doubleSlab) {
		List<BlockETSlab> blocks = new ArrayList<>();
		PropertyETWoodType[] variants = PropertyETWoodType.create("variant", VARIANTS_PER_BLOCK, false);
		for (int i = 0; i < variants.length; i++) {
			PropertyETWoodType variant = variants[i];
			BlockETSlab block = new BlockETSlab(fireproof, i) {
				@Override
				public PropertyETWoodType getVariant() {
					return variant;
				}

				@Override
				public boolean func_176552_j() {
					return doubleSlab;
				}
			};
			blocks.add(block);
		}
		return blocks;
	}

	@Override
	public EnumETLog getWoodType(int meta) {
		meta &= ~8; // unset the top/bottom slab bit
		int variantCount = getVariant().func_177700_c().size();
		int variantMeta = (meta % variantCount) + getBlockNumber() * VARIANTS_PER_BLOCK;
		return EnumETLog.byMetadata(variantMeta);
	}
}

==> binnie-mods-1.11.2-2.1.0.33-sources.jar: binnie/extratrees/block/wood/BlockETSlab.java <==
package binnie.extratrees.block.wood;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.util.ResourceLocation;

import forestry.arboriculture.blocks.BlockForestrySlab;

import binnie.Constants;
import binnie.extratrees.block.EnumETLog;
import binnie.extratrees.block.WoodManager;
import binnie.extratrees.block.property.PropertyETWoodType;

public abstract class BlockETSlab extends BlockForestrySlab<EnumETLog> {
	private BlockETSlab(boolean fireproof, int blockNumber) {
		super(fireproof, blockNumber);
		String name = "slabs.";
		if (fireproof) {
			name += "fireproof.";
		}
		if (func_176552_j()) {
			name += "double.";
		}
		name += blockNumber;
		setRegistryName(new ResourceLocation(Constants.EXTRA_TREES_MOD_ID, name));
		func_149663_c(name);
	}

	@Override
	public String func_150002_b(int meta) {
		EnumETLog woodType = getWoodType(meta);
		return WoodManager.getDisplayName(this, woodType);
	}

	public static List<BlockETSlab> create(boolean fireproof, final boolean doubleSlab) {
		List<BlockETSlab> blocks = new ArrayList<>();
		PropertyETWoodType[] variants = PropertyETWoodType.create("variant", VARIANTS_PER_BLOCK, false);
		for (int i = 0; i < variants.length; i++) {
			PropertyETWoodType variant = variants[i];
			BlockETSlab block = new BlockETSlab(fireproof, i) {
				@Override
				public PropertyETWoodType getVariant() {
					return variant;
				}

				@Override
				public boolean func_176552_j() {
					return doubleSlab;
				}
			};
			blocks.add(block);
		}
		return blocks;
	}

	@Override
	public EnumETLog getWoodType(int meta) {
		meta &= ~8; // unset the top/bottom slab bit
		int variantCount = getVariant().func_177700_c().size();
		int variantMeta = (meta % variantCount) + getBlockNumber() * VARIANTS_PER_BLOCK;
		return EnumETLog.byMetadata(variantMeta);
	}
}
